Ext JS PivotGrid Sample

# Pivot Grid example

This example shows how to create a Pivot Grid backed by an Ext.data.Store.

In this example we are reading a set of 300 records from the server and then pivoting them around Person and Product (on the left axis)
and City and Year (on the top axis). The data are combined automatically, in this case breaking down sales by product and person
over time.

The example code is not minified, so it's readable.